@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Bastien Nocera <hadess@hadess.net>
  *
@@ -501,11 +500,12 @@ get_device_type (XDeviceInfo *dev)
                                  device, prop, 0, 1, False,
                                  XA_ATOM, &realtype, &realformat, &nitems,
                                  &bytes_after, &data);
-        XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), device);
 
         if (gdk_error_trap_pop () || rc != Success || realtype == None)
                 ret = WACOM_TYPE_INVALID;
 
+        xdevice_close (device);
+
         XFree (data);
 
 	return ret;
@@ -1603,14 +1603,27 @@ gsd_wacom_device_class_init (GsdWacomDeviceClass *klass)
 static void
 gsd_wacom_device_init (GsdWacomDevice *device)
 {
+        char *per_user_config;
+
         device->priv = GSD_WACOM_DEVICE_GET_PRIVATE (device);
         device->priv->type = WACOM_TYPE_INVALID;
 
+        per_user_config = g_build_filename (g_get_user_config_dir (), "gnome-settings-daemon", "no-per-machine-config", NULL);
+        if (g_file_test (per_user_config, G_FILE_TEST_EXISTS)) {
+                g_free (per_user_config);
+                goto fallback;
+        }
+        g_free (per_user_config);
+
         if (g_file_get_contents ("/etc/machine-id", &device->priv->machine_id, NULL, NULL) == FALSE)
                 if (g_file_get_contents ("/var/lib/dbus/machine-id", &device->priv->machine_id, NULL, NULL) == FALSE)
-                        device->priv->machine_id = g_strdup ("00000000000000000000000000000000");
+                        goto fallback;
 
         device->priv->machine_id = g_strstrip (device->priv->machine_id);
+        return;
+
+fallback:
+        device->priv->machine_id = g_strdup ("00000000000000000000000000000000");
 }
 
 static void
@@ -1889,7 +1902,7 @@ gsd_wacom_device_get_area (GsdWacomDevice *device)
 				 XA_INTEGER, &realtype, &realformat, &nitems,
 				 &bytes_after, &data);
 	if (gdk_error_trap_pop () || rc != Success || realtype == None || bytes_after != 0 || nitems != 4) {
-		XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdevice);
+		xdevice_close (xdevice);
 		return NULL;
 	}
 
@@ -1898,7 +1911,7 @@ gsd_wacom_device_get_area (GsdWacomDevice *device)
 		device_area[i] = ((long *)data)[i];
 
 	XFree (data);
-	XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdevice);
+	xdevice_close (xdevice);
 
 	return device_area;
 }
