@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -353,6 +352,7 @@ static FixedEntry fixed_entries [] = {
         { "Gtk/ShowUnicodeMenu",     fixed_false_int },
         { "Gtk/AutoMnemonics",       fixed_true_int },
         { "Gtk/EnablePrimaryPaste",  fixed_true_int },
+        { "Gtk/DialogsUseHeader",    fixed_true_int },
 };
 
 static TranslationEntry translations [] = {
